@@ -7,7 +7,7 @@ import yaml
 from typing import Optional
 
 EXPECTED_TF_CONFIG_FILE_NAMES = ["tdfconfig.yml", "tdfconfig.yaml", "validate_configs.yaml", "commit_configs.yaml"]
-TRANSFORM_API_URL = "web-api.prod.transformdata.io"
+TRANSFORM_API_URL = "https://web-api.prod.transformdata.io"
 UPLOAD_MODE_VALIDATE = "validate"
 UPLOAD_MODE_COMMIT = "commit"
 
@@ -57,27 +57,29 @@ def upload_configs(  # noqa: D
     results = {"yaml_files": yaml_files}
     logger.info(f"Files to upload: {yaml_files.keys()}")
     headers = {"Content-Type": "application/json", "Authorization": f"X-Api-Key {api_key}"}
+    url = api_url or TRANSFORM_API_URL
+    verify = url.startswith("https")
 
-    add_files_url = f"https://{api_url or TRANSFORM_API_URL}/api/v1/model/{repo}/{branch}/{commit}/add_model_files"
+    add_files_url = f"{url}/api/v1/model/{repo}/{branch}/{commit}/add_model_files"
     logger.info(f"add_files_url: {add_files_url}")
     logger.info("Uploading config files")
-    r = requests.post(add_files_url, data=json.dumps(results).encode("utf-8"), headers=headers)
+    r = requests.post(add_files_url, data=json.dumps(results).encode("utf-8"), headers=headers, verify=verify)
     if r.status_code != 200:
         raise Exception(f"Failed uploading config yaml files. Error: {r.text}")
 
     if mode == UPLOAD_MODE_VALIDATE:
-        validate_url = f"https://{api_url or TRANSFORM_API_URL}/api/v1/model/{repo}/{branch}/{commit}/validate_model"
+        validate_url = f"{url}/api/v1/model/{repo}/{branch}/{commit}/validate_model"
         logger.info(f"validate_url: {validate_url}")
         logger.info("Checking that uploaded configs are valid and form a valid model")
-        r = requests.post(validate_url, headers=headers)
+        r = requests.post(validate_url, headers=headers, verify=verify)
         if r.status_code != 200:
             raise Exception(f"Failed validating uploaded configs. Error response: {r.text}")
         logger.info("Successfully validated configs")
     elif mode == UPLOAD_MODE_COMMIT:
-        commit_url = f"https://{api_url or TRANSFORM_API_URL}/api/v1/model/{repo}/{branch}/{commit}/commit_model"
+        commit_url = f"{url}/api/v1/model/{repo}/{branch}/{commit}/commit_model"
         logger.info(f"commit_url: {commit_url}")
         logger.info("Committing model")
-        r = requests.post(commit_url, headers=headers)
+        r = requests.post(commit_url, headers=headers, verify=verify)
         if r.status_code != 200:
             raise Exception(f"Failed committing uploaded configs. Error response: {r.text}")
         logger.info("Successfully committed configs")
@@ -104,7 +106,9 @@ if __name__ == "__main__":
         BRANCH = os.getenv("GITHUB_HEAD_REF")
 
     COMMIT = os.getenv("GITHUB_SHA")
-    TRANSFORM_CONFIG_DIR = os.getenv("TRANSFORM_CONFIG_DIR").lstrip().rstrip()
+    TRANSFORM_CONFIG_DIR = os.getenv("TRANSFORM_CONFIG_DIR")
+    if TRANSFORM_CONFIG_DIR:
+        TRANFSFORM_CONFIG_DIR = TRANSFORM_CONFIG_DIR.lstrip().rstrip()
     TRANSFORM_API_KEY = os.environ["TRANSFORM_API_KEY"].lstrip().rstrip()  # fail if TRANSFORM_API_KEY not present
 
     upload_configs(mode, TRANSFORM_API_KEY, REPO, BRANCH, COMMIT, TRANSFORM_CONFIG_DIR)
